@@ -82,24 +82,63 @@ GtkWidget *DurationLabel;
 GtkWidget *DurationValueLabel;
 
 /* TAG Area */
-GtkWidget *TagFrame;
-GtkWidget *TitleEntry;
-GtkWidget *ArtistEntry;
-GtkWidget *AlbumEntry;
-GtkWidget *YearEntry;
-GtkWidget *TrackEntry;
-GtkWidget *TrackTotalEntry;
-GtkWidget *CommentEntry;
-GtkWidget *GenreEntry;
-/* Mini buttons */
-GtkWidget *TitleMButton;
-GtkWidget *ArtistMButton;
-GtkWidget *AlbumMButton;
-GtkWidget *YearMButton;
-GtkWidget *TrackMButton;
-GtkWidget *TrackMButtonSequence;
-GtkWidget *CommentMButton;
-GtkWidget *GenreMButton;
+GtkWidget    *TagFrame;
+GtkWidget    *TagNoteBook;
+GtkWidget    *TitleEntry;
+GtkWidget    *ArtistEntry;
+GtkWidget    *AlbumEntry;
+GtkWidget    *YearEntry;
+GtkWidget    *TrackEntryCombo;
+GtkListStore *TrackEntryComboModel;
+GtkWidget    *TrackTotalEntry;
+GtkWidget    *GenreCombo;
+GtkListStore *GenreComboModel;
+GtkWidget    *CommentEntry;
+//GtkWidget    *CommentView;
+GtkWidget    *ComposerEntry;
+GtkWidget    *OrigArtistEntry;
+GtkWidget    *CopyrightEntry;
+GtkWidget    *URLEntry;
+GtkWidget    *EncodedByEntry;
+GtkWidget    *PictureEntryView;
+GtkListStore *PictureEntryModel;
+// Labels
+GtkWidget    *TitleLabel;
+GtkWidget    *ArtistLabel;
+GtkWidget    *AlbumLabel;
+GtkWidget    *YearLabel;
+GtkWidget    *TrackLabel;
+GtkWidget    *GenreLabel;
+GtkWidget    *CommentLabel;
+GtkWidget    *ComposerLabel;
+GtkWidget    *OrigArtistLabel;
+GtkWidget    *CopyrightLabel;
+GtkWidget    *URLLabel;
+GtkWidget    *EncodedByLabel;
+GtkWidget    *PictureLabel;
+// Mini buttons
+GtkWidget    *TitleMButton;
+GtkWidget    *ArtistMButton;
+GtkWidget    *AlbumMButton;
+GtkWidget    *YearMButton;
+GtkWidget    *TrackMButton;
+GtkWidget    *TrackMButtonSequence;
+GtkWidget    *TrackMButtonNbrFiles;
+GtkWidget    *GenreMButton;
+GtkWidget    *CommentMButton;
+GtkWidget    *ComposerMButton;
+GtkWidget    *OrigArtistMButton;
+GtkWidget    *CopyrightMButton;
+GtkWidget    *URLMButton;
+GtkWidget    *EncodedByMButton;
+GtkWidget    *PictureMButton;
+
+// Other for picture
+GtkWidget *PictureClearButton;
+GtkWidget *PictureAddButton;
+GtkWidget *PictureSaveButton;
+GtkWidget *PicturePropertiesButton;
+GtkWidget *PictureScrollWindow;
 
 GdkCursor *MouseCursor;
 
@@ -137,12 +176,15 @@ void Action_Save_Selected_Files         (void);
 void Action_Undo_From_History_List      (void);
 void Action_Redo_From_History_List      (void);
 void Action_Delete_Selected_Files       (void);
+gint Save_All_Files_With_Answer         (void);
 gint Save_Selected_Files_With_Answer    (void);
 
 void Action_Main_Stop_Button_Pressed    (void);
+void Action_Select_Browser_Style        (void);
 
 void File_Area_Set_Sensitive (gboolean activate);
 void Tag_Area_Set_Sensitive  (gboolean activate);
+void Tag_Area_Display_Controls (ET_File *ETFile);
 
 void Read_Directory                   (gchar *path);
 void Quit_MainWindow                  (void);
