@@ -18,8 +18,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
 
 #include <gtk/gtk.h>
+#include <glib/gi18n-lib.h>
 #include <stdio.h>
 #include <errno.h>
 #include <unistd.h>
@@ -28,8 +30,7 @@
 #include "easytag.h"
 #include "et_core.h"
 #include "misc.h"
-#include "i18n.h"
-
+#include "charset.h"
 #include "libmpg123/mpg123.h"
 
 
@@ -98,7 +99,6 @@ gboolean Mpeg_Header_Read_File_Info (gchar *filename, ET_File_Info *ETFileInfo)
     /* Get size of file */
     filesize = Get_File_Size(filename);
     ETFileInfo->size      = filesize;
-    ETFileList_TotalSize += filesize;
 
     /*
      * This part was taken from XMMS
@@ -196,12 +196,13 @@ gboolean Mpeg_Header_Read_File_Info (gchar *filename, ET_File_Info *ETFileInfo)
         // Duration
         ETFileInfo->duration = mpg123_get_song_time(file)/1000;
         //g_print("time %s\n",Convert_Duration(ETFileInfo->duration));
-        ETFileList_TotalDuration += ETFileInfo->duration;
 
         fclose(file);
     }else
     {
-        g_print(_("ERROR while opening file: '%s' (%s).\n\a"),filename,g_strerror(errno));
+        gchar *filename_utf8 = filename_to_display(filename);
+        g_print(_("ERROR while opening file: '%s' (%s).\n\a"),filename_utf8,g_strerror(errno));
+        g_free(filename_utf8);
         return FALSE;
     }
 
@@ -213,7 +214,7 @@ gboolean Mpeg_Header_Read_File_Info (gchar *filename, ET_File_Info *ETFileInfo)
 /*
  * Display header infos in the main window
  */
-gboolean Mpeg_Header_Display_File_Info_To_UI(gchar *filename, ET_File_Info *ETFileInfo)
+gboolean Mpeg_Header_Display_File_Info_To_UI(gchar *filename_utf8, ET_File_Info *ETFileInfo)
 {
     gchar *text;
     gchar *time = NULL;
@@ -254,20 +255,20 @@ gboolean Mpeg_Header_Display_File_Info_To_UI(gchar *filename, ET_File_Info *ETFi
 
     /* Size */
     size  = Convert_Size(ETFileInfo->size);
-    size1 = Convert_Size(ETFileList_TotalSize);
+    size1 = Convert_Size(ETCore->ETFileDisplayedList_TotalSize);
     text  = g_strdup_printf("%s (%s)",size,size1);
     gtk_label_set_text(GTK_LABEL(SizeValueLabel),text);
-    if (size)  g_free(size);
-    if (size1) g_free(size1);
+    g_free(size);
+    g_free(size1);
     g_free(text);
 
     /* Duration */
     time  = Convert_Duration(ETFileInfo->duration);
-    time1 = Convert_Duration(ETFileList_TotalDuration);
+    time1 = Convert_Duration(ETCore->ETFileDisplayedList_TotalDuration);
     text  = g_strdup_printf("%s (%s)",time,time1);
     gtk_label_set_text(GTK_LABEL(DurationValueLabel),text);
-    if (time)  g_free(time);
-    if (time1) g_free(time1);
+    g_free(time);
+    g_free(time1);
     g_free(text);
 
     return TRUE;
